/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// syntax table for Singular
//
// - search for an exact match of the argument types
// - otherwise search for the first possibility
//   with converted types of the arguments
// - otherwise report an error
//
// operation: ++ (identifier)  ->  nothing
// operation: -- (identifier)  ->  nothing
// operation: - (int)  ->  int
// operation: - (bigint)  ->  bigint
// operation: - (number)  ->  number
// operation: - (poly)  ->  poly
// operation: - (vector)  ->  vector
// operation: - (matrix)  ->  matrix
// operation: - (intvec)  ->  intvec
// operation: - (intmat)  ->  intmat
// operation: - (bigintmat)  ->  bigintmat
// operation: ( (proc)  ->  any_type
// operation: attrib (def)  ->  nothing
// operation: bareiss (bigintmat)  ->  bigintmat
// operation: bareiss (module)  ->  list
// operation: betti (list)  ->  intmat
// operation: betti (resolution)  ->  intmat
// operation: betti (ideal)  ->  intmat
// operation: betti (module)  ->  intmat
// operation: bigint (bigint)  ->  bigint
// operation: bigint (number)  ->  bigint
// operation: bigint (poly)  ->  bigint
// operation: bigintmat (bigintmat)  ->  bigintmat
// operation: char (ring)  ->  int
// operation: char_series (ideal)  ->  matrix
// operation: charstr (ring)  ->  string
// operation: close (link)  ->  nothing
// operation: ncols (matrix)  ->  int
// operation: ncols (ideal)  ->  int
// operation: ncols (module)  ->  int
// operation: ncols (intmat)  ->  int
// operation: ncols (bigintmat)  ->  int
// DUMMY // operation: ncols (intvec)  ->  $INVALID$
// operation: cleardenom (poly)  ->  poly
// operation: cleardenom (vector)  ->  vector
// operation: size (bigint)  ->  int
// operation: size (number)  ->  int
// operation: size (resolution)  ->  int
// operation: size (string)  ->  int
// operation: size (poly)  ->  int
// operation: size (vector)  ->  int
// operation: size (ideal)  ->  int
// operation: size (module)  ->  int
// operation: size (matrix)  ->  int
// operation: size (intvec)  ->  int
// operation: size (intmat)  ->  int
// operation: size (list)  ->  int
// operation: size (ring)  ->  int
// operation: cring (ring)  ->  cring
// operation: def (int)  ->  def
// DUMMY // operation: def (any_type)  ->  $INVALID$
// operation: deg (poly)  ->  int
// operation: deg (vector)  ->  int
// operation: deg (matrix)  ->  int
// operation: degree (ideal)  ->  string
// operation: degree (module)  ->  string
// operation: defined (def)  ->  int
// operation: denominator (number)  ->  number
// operation: numerator (number)  ->  number
// operation: det (bigintmat)  ->  bigint
// operation: det (intmat)  ->  int
// operation: det (matrix)  ->  poly
// operation: det (module)  ->  poly
// operation: dim (ideal)  ->  int
// operation: dim (module)  ->  int
// operation: dim (resolution)  ->  int
// operation: dump (link)  ->  nothing
// operation: gen (int)  ->  vector
// WARNING: gen requires currRing
// operation: execute (string)  ->  nothing
// operation: ERROR (string)  ->  nothing
// operation: factorize (poly)  ->  list
// operation: finduni (ideal)  ->  ideal
// operation: freemodule (int)  ->  module
// WARNING: freemodule requires currRing
// operation: facstd (ideal)  ->  list
// operation: getdump (link)  ->  nothing
// operation: highcorner (ideal)  ->  poly
// operation: highcorner (module)  ->  vector
// operation: hilb (ideal)  ->  nothing
// operation: hilb (module)  ->  nothing
// operation: hilb (intvec)  ->  intvec
// operation: homog (ideal)  ->  int
// operation: homog (module)  ->  int
// operation: ideal (ideal)  ->  ideal
// operation: ideal (vector)  ->  ideal
// operation: ideal (matrix)  ->  ideal
// operation: ideal (ring)  ->  ideal
// WARNING: ideal requires currRing
// operation: ideal (map)  ->  ideal
// operation: impart (number)  ->  number
// operation: indepSet (ideal)  ->  intvec
// operation: int (int)  ->  int
// operation: int (bigint)  ->  int
// operation: int (number)  ->  int
// operation: int (poly)  ->  int
// operation: interred (ideal)  ->  ideal
// operation: interred (module)  ->  module
// operation: intmat (bigintmat)  ->  intmat
// operation: intmat (intmat)  ->  intmat
// operation: intvec (intmat)  ->  intvec
// operation: intvec (intvec)  ->  intvec
// operation: rvar (poly)  ->  int
// operation: rvar (string)  ->  int
// operation: rvar (any_type)  ->  int
// operation: jacob (poly)  ->  ideal
// operation: jacob (ideal)  ->  matrix
// operation: jacob (module)  ->  module
// operation: janet (ideal)  ->  ideal
// operation: kbase (ideal)  ->  ideal
// operation: kbase (module)  ->  module
// operation: ludecomp (matrix)  ->  list
// operation: primefactors (bigint)  ->  list
// operation: primefactors (number)  ->  list
// operation: killattrib (identifier)  ->  nothing
// operation: lead (poly)  ->  poly
// operation: lead (ideal)  ->  ideal
// operation: lead (vector)  ->  vector
// operation: lead (module)  ->  module
// operation: leadcoef (poly)  ->  number
// operation: leadcoef (vector)  ->  number
// operation: leadexp (poly)  ->  intvec
// operation: leadexp (vector)  ->  intvec
// operation: leadmonom (poly)  ->  poly
// operation: leadmonom (vector)  ->  vector
// operation: link (link)  ->  link
// operation: list (def)  ->  list
// DUMMY // operation: map (any_type)  ->  $INVALID$
// operation: matrix (matrix)  ->  matrix
// operation: maxideal (int)  ->  ideal
// WARNING: maxideal requires currRing
// operation: memory (int)  ->  bigint
// operation: minbase (ideal)  ->  ideal
// operation: minbase (module)  ->  module
// operation: minres (list)  ->  list
// operation: minres (resolution)  ->  resolution
// operation: module (module)  ->  module
// operation: monitor (link)  ->  nothing
// operation: monomial (intvec)  ->  poly
// WARNING: monomial requires currRing
// operation: mult (ideal)  ->  int
// operation: mult (module)  ->  int
// operation: mstd (ideal)  ->  list
// operation: mstd (module)  ->  list
// operation: nameof (any_type)  ->  string
// operation: names (int)  ->  list
// operation: names (package)  ->  list
// operation: names (ring)  ->  list
// operation: not (int)  ->  int
// operation: number (number)  ->  number
// operation: number (poly)  ->  number
// operation: number (bigint)  ->  number
// WARNING: number requires currRing
// operation: $INVALID$ ($INVALID$)  ->  $INVALID$
// operation: npars (ring)  ->  int
// operation: nvars (ring)  ->  int
// operation: open (link)  ->  nothing
// operation: option (def)  ->  nothing
// operation: ord (poly)  ->  int
// operation: ord (vector)  ->  int
// operation: ordstr (ring)  ->  string
// operation: par (int)  ->  number
// WARNING: par requires currRing
// operation: pardeg (number)  ->  int
// operation: parstr (int)  ->  string
// operation: parstr (ring)  ->  string
// operation: poly (poly)  ->  poly
// operation: poly (bigint)  ->  poly
// WARNING: poly requires currRing
// operation: preimage (map)  ->  ring
// operation: prime (int)  ->  int
// operation: print (list)  ->  string
// operation: print (def)  ->  string
// operation: proc (proc)  ->  proc
// operation: prune (module)  ->  module
// operation: qhweight (ideal)  ->  intvec
// operation: qhweight (module)  ->  intvec
// operation: rank (matrix)  ->  int
// operation: read (link)  ->  string
// operation: regularity (list)  ->  int
// operation: repart (number)  ->  number
// operation: reservedName (string)  ->  int
// operation: resolution (list)  ->  resolution
// WARNING: resolution requires currRing
// operation: resolution (resolution)  ->  resolution
// operation: ringlist (ring)  ->  list
// operation: ring_list (cring)  ->  list
// operation: ring_list (ring)  ->  list
// operation: ring (ring)  ->  ring
// operation: ring (list)  ->  ring
// operation: nrows (vector)  ->  int
// operation: nrows (module)  ->  int
// operation: nrows (matrix)  ->  int
// operation: nrows (intmat)  ->  int
// operation: nrows (bigintmat)  ->  int
// operation: nrows (intvec)  ->  int
// operation: sba (ideal)  ->  ideal
// operation: sba (module)  ->  module
// operation: setring (ring)  ->  nothing
// operation: slimgb (ideal)  ->  ideal
// operation: slimgb (module)  ->  module
// operation: sortvec (ideal)  ->  intvec
// operation: sortvec (module)  ->  intvec
// operation: sqrfree (poly)  ->  list
// operation: std (ideal)  ->  ideal
// operation: std (module)  ->  module
// operation: string (string)  ->  string
// operation: syz (ideal)  ->  module
// operation: syz (module)  ->  module
// operation: envelope (ring)  ->  ring
// operation: opposite (ring)  ->  ring
// operation: twostd (ideal)  ->  ideal
// DUMMY // operation: trace (intvec)  ->  $INVALID$
// DUMMY // operation: trace (ideal)  ->  $INVALID$
// operation: trace (intmat)  ->  int
// operation: trace (matrix)  ->  poly
// operation: transpose (intvec)  ->  intmat
// operation: transpose (intmat)  ->  intmat
// operation: transpose (bigintmat)  ->  bigintmat
// operation: transpose (matrix)  ->  matrix
// operation: transpose (module)  ->  module
// operation: typeof (any_type)  ->  string
// operation: univariate (poly)  ->  int
// operation: variables (poly)  ->  ideal
// operation: variables (ideal)  ->  ideal
// operation: variables (matrix)  ->  ideal
// operation: vector (vector)  ->  vector
// operation: vdim (ideal)  ->  int
// operation: vdim (module)  ->  int
// operation: var (int)  ->  poly
// WARNING: var requires currRing
// operation: varstr (int)  ->  string
// operation: varstr (ring)  ->  string
// operation: weight (ideal)  ->  intvec
// operation: weight (module)  ->  intvec
// operation: load (string)  ->  nothing
// operation: convhull (ideal)  ->  ideal
// operation: waitfirst (list)  ->  int
// operation: waitall (list)  ->  int
/*---------------------------------------------*/
// operation: :: (def, def)  ->  any_type
// operation: + (int, int)  ->  int
// operation: + (bigint, bigint)  ->  bigint
// operation: + (number, number)  ->  number
// operation: + (poly, poly)  ->  poly
// operation: + (vector, vector)  ->  vector
// operation: + (ideal, ideal)  ->  ideal
// operation: + (module, module)  ->  module
// operation: + (poly, matrix)  ->  matrix
// operation: + (matrix, poly)  ->  matrix
// operation: + (matrix, matrix)  ->  matrix
// operation: + (string, string)  ->  string
// operation: + (bigintmat, bigintmat)  ->  bigintmat
// operation: + (bigintmat, int)  ->  bigintmat
// operation: + (int, bigintmat)  ->  bigintmat
// operation: + (bigintmat, bigint)  ->  bigintmat
// operation: + (bigint, bigintmat)  ->  bigintmat
// operation: + (intvec, int)  ->  intvec
// operation: + (int, intvec)  ->  intvec
// operation: + (intmat, int)  ->  intmat
// operation: + (int, intmat)  ->  intmat
// operation: + (intvec, intvec)  ->  intvec
// operation: + (intmat, intmat)  ->  intmat
// operation: + (list, list)  ->  list
// operation: + (ring, ring)  ->  ring
// operation: - (int, int)  ->  int
// operation: - (bigint, bigint)  ->  bigint
// operation: - (number, number)  ->  number
// operation: - (poly, poly)  ->  poly
// operation: - (vector, vector)  ->  vector
// operation: - (matrix, poly)  ->  matrix
// operation: - (matrix, matrix)  ->  matrix
// operation: - (bigintmat, bigintmat)  ->  bigintmat
// operation: - (bigintmat, int)  ->  bigintmat
// operation: - (int, bigintmat)  ->  bigintmat
// operation: - (bigintmat, bigint)  ->  bigintmat
// operation: - (bigint, bigintmat)  ->  bigintmat
// operation: - (intvec, int)  ->  intvec
// operation: - (intmat, int)  ->  intmat
// operation: - (intvec, intvec)  ->  intvec
// operation: - (intmat, intmat)  ->  intmat
// DUMMY // operation: - (ideal, ideal)  ->  nothing
// DUMMY // operation: - (module, module)  ->  nothing
// operation: * (int, int)  ->  int
// operation: * (bigint, bigint)  ->  bigint
// operation: * (number, number)  ->  number
// operation: * (poly, poly)  ->  poly
// operation: * (poly, vector)  ->  vector
// operation: * (vector, poly)  ->  vector
// operation: * (ideal, poly)  ->  ideal
// operation: * (poly, ideal)  ->  ideal
// operation: * (module, poly)  ->  module
// operation: * (poly, module)  ->  module
// operation: * (ideal, ideal)  ->  ideal
// operation: * (ideal, vector)  ->  module
// operation: * (vector, ideal)  ->  module
// operation: * (ideal, module)  ->  module
// operation: * (module, ideal)  ->  module
// operation: * (matrix, poly)  ->  matrix
// operation: * (poly, matrix)  ->  matrix
// operation: * (matrix, number)  ->  matrix
// operation: * (number, matrix)  ->  matrix
// operation: * (matrix, int)  ->  matrix
// operation: * (int, matrix)  ->  matrix
// operation: * (matrix, matrix)  ->  matrix
// operation: * (matrix, bigint)  ->  matrix
// operation: * (bigint, matrix)  ->  matrix
// operation: * (bigintmat, bigintmat)  ->  bigintmat
// operation: * (bigintmat, int)  ->  bigintmat
// operation: * (int, bigintmat)  ->  bigintmat
// operation: * (bigintmat, bigint)  ->  bigintmat
// operation: * (bigint, bigintmat)  ->  bigintmat
// operation: * (intvec, int)  ->  intvec
// operation: * (int, intvec)  ->  intvec
// operation: * (intmat, int)  ->  intmat
// operation: * (int, intmat)  ->  intmat
// operation: * (intmat, intvec)  ->  intvec
// operation: * (intmat, intmat)  ->  intmat
// operation: * (intvec, intmat)  ->  intmat
// operation: / (number, number)  ->  number
// operation: / (poly, poly)  ->  poly
// operation: / (vector, poly)  ->  vector
// operation: / (matrix, poly)  ->  matrix
// operation: / (int, int)  ->  int
// operation: / (bigint, bigint)  ->  bigint
// operation: / (intvec, int)  ->  intvec
// operation: / (intmat, int)  ->  intmat
// operation: / (cring, int)  ->  cring
// operation: / (cring, bigint)  ->  cring
// operation: div (int, int)  ->  int
// operation: div (bigint, bigint)  ->  bigint
// operation: div (intvec, int)  ->  intvec
// operation: div (intmat, int)  ->  intmat
// operation: % (int, int)  ->  int
// operation: % (bigint, bigint)  ->  bigint
// operation: % (intvec, int)  ->  intvec
// operation: % (intmat, int)  ->  intmat
// operation: % (number, number)  ->  number
// operation: ^ (int, int)  ->  int
// operation: ^ (bigint, int)  ->  bigint
// operation: ^ (number, int)  ->  number
// operation: ^ (poly, int)  ->  poly
// operation: ^ (ideal, int)  ->  ideal
// operation: <= (int, int)  ->  int
// operation: <= (bigint, bigint)  ->  int
// operation: <= (number, number)  ->  int
// operation: <= (string, string)  ->  int
// operation: <= (intvec, int)  ->  int
// operation: <= (intvec, intvec)  ->  int
// operation: <= (poly, poly)  ->  int
// operation: <= (vector, vector)  ->  int
// operation: <= (matrix, matrix)  ->  int
// operation: < (int, int)  ->  int
// operation: < (bigint, bigint)  ->  int
// operation: < (number, number)  ->  int
// operation: < (intvec, int)  ->  int
// operation: < (intvec, intvec)  ->  int
// operation: < (string, string)  ->  int
// operation: < (poly, poly)  ->  int
// operation: < (vector, vector)  ->  int
// operation: < (matrix, matrix)  ->  int
// operation: >= (int, int)  ->  int
// operation: >= (bigint, bigint)  ->  int
// operation: >= (number, number)  ->  int
// operation: >= (string, string)  ->  int
// operation: >= (intvec, int)  ->  int
// operation: >= (intvec, intvec)  ->  int
// operation: >= (poly, poly)  ->  int
// operation: >= (vector, vector)  ->  int
// operation: >= (matrix, matrix)  ->  int
// operation: > (int, int)  ->  int
// operation: > (bigint, bigint)  ->  int
// operation: > (number, number)  ->  int
// operation: > (string, string)  ->  int
// operation: > (intvec, int)  ->  int
// operation: > (intvec, intvec)  ->  int
// operation: > (poly, poly)  ->  int
// operation: > (vector, vector)  ->  int
// operation: > (matrix, matrix)  ->  int
// operation: and (int, int)  ->  int
// operation: or (int, int)  ->  int
// operation: == (int, int)  ->  int
// operation: == (ring, int)  ->  int
// operation: == (ring, ring)  ->  int
// operation: == (bigint, bigint)  ->  int
// operation: == (number, number)  ->  int
// operation: == (string, string)  ->  int
// operation: == (poly, poly)  ->  int
// operation: == (vector, vector)  ->  int
// operation: == (intvec, int)  ->  int
// operation: == (intvec, intvec)  ->  int
// operation: == (intmat, intmat)  ->  int
// operation: == (bigintmat, bigintmat)  ->  int
// operation: == (cring, cring)  ->  int
// operation: == (matrix, matrix)  ->  int
// operation: == (ring, ring)  ->  int
// DUMMY // operation: == (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: == (module, module)  ->  $INVALID$
// DUMMY // operation: == (ideal, module)  ->  $INVALID$
// DUMMY // operation: == (module, ideal)  ->  $INVALID$
// operation: <> (int, int)  ->  int
// operation: <> (bigint, bigint)  ->  int
// operation: <> (number, number)  ->  int
// operation: <> (string, string)  ->  int
// operation: <> (poly, poly)  ->  int
// operation: <> (vector, vector)  ->  int
// operation: <> (intvec, intvec)  ->  int
// operation: <> (intmat, intmat)  ->  int
// operation: <> (matrix, matrix)  ->  int
// DUMMY // operation: <> (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: <> (module, module)  ->  $INVALID$
// DUMMY // operation: <> (ideal, module)  ->  $INVALID$
// DUMMY // operation: <> (module, ideal)  ->  $INVALID$
// operation: <> (ring, ring)  ->  int
// operation: .. (int, int)  ->  intvec
// operation: [ (intvec, int)  ->  int
// operation: [ (intvec, intvec)  ->  int
// operation: [ (ideal, int)  ->  poly
// operation: [ (map, int)  ->  poly
// operation: [ (ideal, intvec)  ->  poly
// operation: [ (module, int)  ->  vector
// operation: [ (module, intvec)  ->  vector
// operation: [ (string, int)  ->  string
// operation: [ (string, intvec)  ->  string
// operation: [ (list, int)  ->  any_type
// operation: [ (list, intvec)  ->  any_type
// operation: [ (poly, int)  ->  poly
// operation: [ (poly, intvec)  ->  poly
// operation: [ (vector, int)  ->  poly
// operation: [ (vector, intvec)  ->  vector
// operation: [ (cring, any_type)  ->  ring
// operation: ( (proc, def)  ->  any_type
// operation: ( (map, def)  ->  any_type
// operation: ( (LIB, string)  ->  nothing
// operation: ( (any_type, int)  ->  any_type
// operation: ( (any_type, intvec)  ->  any_type
// operation: : (int, int)  ->  intvec
// operation: align (vector, int)  ->  vector
// operation: align (module, int)  ->  module
// operation: attrib (def, string)  ->  nothing
// operation: betti (list, int)  ->  intmat
// operation: betti (resolution, int)  ->  intmat
// operation: betti (ideal, int)  ->  intmat
// operation: betti (module, int)  ->  intmat
// operation: bracket (poly, poly)  ->  poly
// operation: chinrem (intvec, intvec)  ->  bigint
// operation: chinrem (list, intvec)  ->  any_type
// operation: chinrem (list, list)  ->  any_type
// operation: coef (poly, poly)  ->  matrix
// operation: coeffs (ideal, poly)  ->  matrix
// operation: coeffs (module, poly)  ->  matrix
// operation: coeffs (ideal, ideal)  ->  matrix
// operation: coeffs (module, module)  ->  matrix
// operation: contract (ideal, ideal)  ->  matrix
// operation: deg (poly, intvec)  ->  int
// operation: deg (vector, intvec)  ->  int
// operation: deg (matrix, intvec)  ->  int
// operation: delete (list, int)  ->  list
// operation: diff (poly, poly)  ->  poly
// operation: diff (vector, poly)  ->  vector
// operation: diff (ideal, poly)  ->  ideal
// operation: diff (ideal, ideal)  ->  matrix
// operation: diff (module, poly)  ->  module
// operation: diff (matrix, poly)  ->  matrix
// operation: diff (number, number)  ->  number
// operation: dim (ideal, ideal)  ->  int
// operation: dim (module, ideal)  ->  int
// operation: division (ideal, ideal)  ->  list
// operation: division (module, module)  ->  list
// operation: eliminate (ideal, poly)  ->  ideal
// operation: eliminate (module, poly)  ->  module
// operation: eliminate (ideal, intvec)  ->  ideal
// operation: eliminate (module, intvec)  ->  module
// operation: exportto (package, identifier)  ->  nothing
// operation: extgcd (int, int)  ->  list
// operation: extgcd (bigint, bigint)  ->  list
// operation: extgcd (poly, poly)  ->  list
// operation: factorize (poly, int)  ->  ideal
// operation: facstd (ideal, ideal)  ->  list
// operation: farey (bigint, bigint)  ->  number
// WARNING: farey requires currRing
// operation: farey (ideal, bigint)  ->  ideal
// operation: farey (module, bigint)  ->  module
// operation: farey (matrix, bigint)  ->  matrix
// operation: farey (list, bigint)  ->  list
// operation: fetch (ring, any_type)  ->  any_type
// operation: fglm (ring, def)  ->  ideal
// WARNING: fglm requires currRing
// operation: fglmquot (ideal, poly)  ->  ideal
// operation: find (string, string)  ->  int
// operation: frwalk (ring, def)  ->  ideal
// WARNING: frwalk requires currRing
// operation: gcd (int, int)  ->  int
// operation: gcd (number, number)  ->  number
// operation: gcd (bigint, bigint)  ->  bigint
// operation: gcd (poly, poly)  ->  poly
// operation: hilb (ideal, int)  ->  intvec
// operation: hilb (module, int)  ->  intvec
// operation: homog (ideal, intvec)  ->  int
// operation: homog (module, intvec)  ->  int
// operation: homog (poly, poly)  ->  poly
// operation: homog (vector, poly)  ->  vector
// operation: homog (ideal, poly)  ->  ideal
// operation: homog (module, poly)  ->  module
// operation: hres (ideal, int)  ->  resolution
// operation: imap (ring, any_type)  ->  any_type
// operation: importfrom (package, any_type)  ->  nothing
// operation: indepSet (ideal, int)  ->  list
// operation: insert (list, def)  ->  list
// operation: interpolation (list, intvec)  ->  ideal
// WARNING: interpolation requires currRing
// operation: intersect (ideal, ideal)  ->  ideal
// operation: intersect (module, module)  ->  module
// operation: janet (ideal, int)  ->  ideal
// operation: jet (poly, int)  ->  poly
// operation: jet (ideal, int)  ->  ideal
// operation: jet (vector, int)  ->  vector
// operation: jet (module, int)  ->  module
// operation: jet (matrix, int)  ->  matrix
// operation: kbase (ideal, int)  ->  ideal
// operation: kbase (module, int)  ->  module
// operation: kernel (ring, any_type)  ->  ideal
// WARNING: kernel requires currRing
// operation: killattrib (identifier, string)  ->  nothing
// operation: koszul (int, int)  ->  matrix
// WARNING: koszul requires currRing
// operation: koszul (int, ideal)  ->  matrix
// operation: kres (ideal, int)  ->  resolution
// operation: lift (ideal, ideal)  ->  matrix
// operation: lift (module, module)  ->  matrix
// operation: liftstd (ideal, matrix)  ->  ideal
// operation: liftstd (module, matrix)  ->  module
// operation: load (string, string)  ->  nothing
// operation: lres (ideal, int)  ->  resolution
// operation: modulo (ideal, ideal)  ->  module
// operation: modulo (module, module)  ->  module
// operation: monitor (link, string)  ->  nothing
// operation: mpresmat (ideal, int)  ->  module
// operation: newstruct (string, string)  ->  nothing
// operation: mres (ideal, int)  ->  resolution
// operation: mres (module, int)  ->  resolution
// operation: primefactors (bigint, int)  ->  list
// operation: primefactors (number, int)  ->  list
// operation: ncalgebra (poly, poly)  ->  nothing
// operation: ncalgebra (poly, matrix)  ->  nothing
// operation: ncalgebra (matrix, poly)  ->  nothing
// operation: ncalgebra (matrix, matrix)  ->  nothing
// operation: nc_algebra (poly, poly)  ->  ring
// operation: nc_algebra (poly, matrix)  ->  ring
// operation: nc_algebra (matrix, poly)  ->  ring
// operation: nc_algebra (matrix, matrix)  ->  ring
// operation: oppose (ring, def)  ->  any_type
// operation: parstr (ring, int)  ->  string
// operation: print (def, string)  ->  string
// operation: quotient (ideal, ideal)  ->  ideal
// operation: quotient (module, ideal)  ->  module
// operation: quotient (module, module)  ->  ideal
// operation: random (int, int)  ->  int
// operation: rank (matrix, int)  ->  int
// operation: read (link, string)  ->  string
// operation: reduce (poly, ideal)  ->  poly
// operation: reduce (vector, ideal)  ->  vector
// operation: reduce (vector, module)  ->  vector
// operation: reduce (ideal, ideal)  ->  ideal
// operation: reduce (module, ideal)  ->  module
// operation: reduce (module, module)  ->  module
// operation: nres (ideal, int)  ->  resolution
// operation: nres (module, int)  ->  resolution
// operation: sba (ideal, int)  ->  ideal
// operation: sba (module, int)  ->  module
// operation: simplify (poly, int)  ->  poly
// operation: simplify (vector, int)  ->  vector
// operation: simplify (ideal, int)  ->  ideal
// operation: simplify (module, int)  ->  module
// operation: sqrfree (poly, int)  ->  ideal
// operation: status (link, string)  ->  string
// operation: status (list, int)  ->  int
// operation: sres (ideal, int)  ->  resolution
// operation: sres (module, int)  ->  resolution
// operation: std (ideal, poly)  ->  ideal
// operation: std (module, vector)  ->  module
// operation: std (ideal, ideal)  ->  ideal
// operation: std (module, module)  ->  module
// operation: std (ideal, intvec)  ->  ideal
// operation: std (module, intvec)  ->  module
// operation: syz (ideal, string)  ->  module
// operation: syz (module, string)  ->  module
// operation: varstr (ring, int)  ->  string
// operation: waitfirst (list, int)  ->  int
// operation: waitall (list, int)  ->  int
// operation: wedge (matrix, int)  ->  matrix
/*---------------------------------------------*/
// operation: [ (string, int, int)  ->  string
// operation: [ (intmat, int, int)  ->  int
// operation: [ (bigintmat, int, int)  ->  bigint
// operation: [ (intmat, int, intvec)  ->  int
// operation: [ (bigintmat, int, intvec)  ->  bigint
// operation: [ (intmat, intvec, int)  ->  int
// operation: [ (bigintmat, intvec, int)  ->  bigint
// operation: [ (intmat, intvec, intvec)  ->  int
// operation: [ (bigintmat, intvec, intvec)  ->  bigint
// operation: [ (matrix, int, int)  ->  poly
// operation: [ (matrix, int, intvec)  ->  poly
// operation: [ (matrix, intvec, int)  ->  poly
// operation: [ (matrix, intvec, intvec)  ->  poly
// operation: [ (cring, any_type, any_type)  ->  ring
// operation: ( (proc, def, def)  ->  any_type
// operation: attrib (identifier, string, def)  ->  nothing
// operation: bareiss (module, int, int)  ->  list
// operation: coeffs (poly, poly, matrix)  ->  matrix
// operation: coeffs (vector, poly, matrix)  ->  matrix
// operation: coeffs (ideal, poly, matrix)  ->  matrix
// operation: coeffs (module, poly, matrix)  ->  matrix
// operation: coeffs (ideal, ideal, poly)  ->  matrix
// operation: coeffs (module, module, poly)  ->  matrix
// operation: eliminate (ideal, poly, intvec)  ->  ideal
// operation: eliminate (module, poly, intvec)  ->  module
// operation: find (string, string, int)  ->  int
// operation: frwalk (ring, def, int)  ->  ideal
// WARNING: frwalk requires currRing
// operation: hilb (ideal, int, intvec)  ->  intvec
// operation: hilb (module, int, intvec)  ->  intvec
// operation: homog (poly, poly, intvec)  ->  poly
// operation: homog (vector, poly, intvec)  ->  vector
// operation: homog (ideal, poly, intvec)  ->  ideal
// operation: homog (module, poly, intvec)  ->  module
// operation: insert (list, def, int)  ->  list
// operation: intmat (intmat, int, int)  ->  intmat
// operation: jet (poly, int, intvec)  ->  poly
// operation: jet (ideal, int, intvec)  ->  ideal
// operation: jet (vector, int, intvec)  ->  vector
// operation: jet (module, int, intvec)  ->  module
// operation: jet (poly, poly, int)  ->  poly
// operation: jet (vector, poly, int)  ->  vector
// operation: jet (ideal, matrix, int)  ->  ideal
// operation: jet (module, matrix, int)  ->  module
// DUMMY // operation: jet (poly, int, int)  ->  poly
// operation: koszul (int, int, ideal)  ->  matrix
// operation: lift (ideal, ideal, matrix)  ->  matrix
// operation: lift (module, module, matrix)  ->  matrix
// operation: liftstd (ideal, matrix, module)  ->  ideal
// operation: liftstd (module, matrix, module)  ->  module
// operation: matrix (ideal, int, int)  ->  matrix
// operation: matrix (module, int, int)  ->  matrix
// operation: matrix (matrix, int, int)  ->  matrix
// operation: newstruct (string, string, string)  ->  nothing
// operation: preimage (ring, any_type, any_type)  ->  ideal
// WARNING: preimage requires currRing
// operation: random (int, int, int)  ->  intmat
// operation: reduce (poly, ideal, int)  ->  poly
// operation: reduce (vector, ideal, int)  ->  vector
// operation: reduce (vector, module, int)  ->  vector
// operation: reduce (ideal, ideal, int)  ->  ideal
// operation: reduce (module, module, int)  ->  module
// operation: reduce (module, ideal, int)  ->  module
// operation: reduce (poly, poly, ideal)  ->  poly
// operation: reduce (vector, poly, module)  ->  vector
// operation: reduce (ideal, ideal, matrix)  ->  ideal
// operation: reduce (module, module, matrix)  ->  module
// operation: resultant (poly, poly, poly)  ->  poly
// operation: ring (def, def, def)  ->  ring
// operation: sba (ideal, int, int)  ->  ideal
// operation: sba (module, int, int)  ->  module
// operation: status (link, string, string)  ->  int
// operation: std (ideal, intvec, intvec)  ->  ideal
// operation: std (module, intvec, intvec)  ->  module
// operation: subst (poly, poly, poly)  ->  poly
// operation: subst (vector, poly, poly)  ->  vector
// operation: subst (ideal, poly, poly)  ->  ideal
// operation: subst (module, poly, poly)  ->  module
// operation: subst (matrix, poly, poly)  ->  matrix
// operation: subst (matrix, poly, int)  ->  matrix
// operation: subst (matrix, poly, number)  ->  matrix
// operation: laguerre (poly, int, int)  ->  list
// operation: vandermonde (ideal, ideal, int)  ->  poly
/*---------------------------------------------*/
// operation: ( (...)  ->  any_type ( number of arguments >0 )
// operation: [ (...)  ->  ring ( number of arguments >0 )
// operation: breakpoint (...)  ->  nothing ( 0 arguments )
// operation: breakpoint (...)  ->  nothing ( number of arguments >0 )
// operation: branchTo (...)  ->  nothing ( number of arguments >0 )
// operation: coef (...)  ->  matrix ( 2 arguments )
// operation: coef (...)  ->  nothing ( 4 arguments )
// operation: division (...)  ->  any_type ( 2 arguments )
// operation: division (...)  ->  any_type ( 3 arguments )
// operation: division (...)  ->  any_type ( 4 arguments )
// operation: dbprint (...)  ->  nothing ( number of arguments >0 )
// operation: fetch (...)  ->  any_type ( 2 arguments )
// operation: fetch (...)  ->  any_type ( 3 arguments )
// operation: fetch (...)  ->  any_type ( 4 arguments )
// operation: ideal (...)  ->  ideal ( 1 arguments )
// operation: ideal (...)  ->  ideal ( any number of arguments )
// operation: intersect (...)  ->  ideal ( 2 arguments )
// operation: intersect (...)  ->  ideal ( number of arguments >0 )
// operation: intvec (...)  ->  intvec ( 1 arguments )
// operation: intvec (...)  ->  intvec ( number of arguments >0 )
// operation: jet (...)  ->  poly ( 2 arguments )
// operation: jet (...)  ->  poly ( 3 arguments )
// operation: jet (...)  ->  poly ( 4 arguments )
// operation: LIB (...)  ->  nothing ( 1 arguments )
// operation: lift (...)  ->  matrix ( 2 arguments )
// operation: lift (...)  ->  matrix ( 3 arguments )
// operation: lift (...)  ->  matrix ( 4 arguments )
// operation: liftstd (...)  ->  module ( 2 arguments )
// operation: liftstd (...)  ->  module ( 3 arguments )
// operation: liftstd (...)  ->  module ( 4 arguments )
// operation: list (...)  ->  list ( any number of arguments )
// operation: luinverse (...)  ->  list ( number of arguments >0 )
// operation: lusolve (...)  ->  list ( number of arguments >0 )
// operation: minor (...)  ->  nothing ( 1 arguments )
// operation: minor (...)  ->  ideal ( number of arguments >0 )
// operation: module (...)  ->  module ( 1 arguments )
// operation: module (...)  ->  module ( any number of arguments )
// operation: names (...)  ->  list ( 1 arguments )
// operation: names (...)  ->  list ( 0 arguments )
// operation: $INVALID$ (...)  ->  $INVALID$ ( 2 arguments )
// operation: option (...)  ->  string ( any number of arguments )
// operation: reduce (...)  ->  ideal ( 2 arguments )
// operation: reduce (...)  ->  ideal ( 3 arguments )
// operation: reduce (...)  ->  ideal ( 4 arguments )
// operation: reduce (...)  ->  ideal ( 5 arguments )
// operation: reservedName (...)  ->  int ( 1 arguments )
// operation: reservedName (...)  ->  nothing ( 0 arguments )
// operation: string (...)  ->  string ( any number of arguments )
// operation: subst (...)  ->  nothing ( 3 arguments )
// operation: subst (...)  ->  nothing ( number of arguments >0 )
// operation: system (...)  ->  nothing ( number of arguments >0 )
// operation: test (...)  ->  nothing ( number of arguments >0 )
// operation: write (...)  ->  nothing ( number of arguments >0 )
// operation: status (...)  ->  string ( 2 arguments )
// operation: status (...)  ->  int ( 3 arguments )
// operation: status (...)  ->  int ( 4 arguments )
// operation: simplex (...)  ->  list ( 6 arguments )
// operation: uressolve (...)  ->  list ( 4 arguments )
// operation: std (...)  ->  ideal ( 1 arguments )
// operation: std (...)  ->  ideal ( 2 arguments )
// operation: std (...)  ->  ideal ( 3 arguments )
// operation: std (...)  ->  ideal ( 4 arguments )
// operation: qrds (...)  ->  list ( 4 arguments )
// operation: factmodd (...)  ->  list ( number of arguments >0 )
/*---------------------------------------------*/
// assign: ideal =  ideal
// assign: ideal =  matrix
// assign: resolution =  resolution
// assign: int =  int
// assign: int =  intmat
// assign: matrix =  matrix
// assign: map =  ideal
// assign: map =  map
// assign: module =  module
// assign: module =  poly
// assign: poly =  poly
// assign: poly =  matrix
// assign: ring =  ring
// assign: ring =  ideal
// assign: cring =  cring
// assign: string =  string
// assign: proc =  string
// assign: proc =  proc
// assign: vector =  vector
// assign: intvec =  intvec
// assign: intmat =  intmat
// assign: bigintmat =  bigintmat
// assign: number =  number
// assign: bigint =  bigint
// assign: list =  resolution
// assign: list =  list
// assign: link =  string
// assign: link =  link
// assign: package =  package
// assign: def =  def
/*---------------------------------------------*/
// convert intmat -> bigintmat
// convert intvec -> intmat
// convert poly -> ideal
// convert bigint -> ideal
// convert int -> ideal
// convert intmat -> matrix
// convert ideal -> matrix
// convert module -> matrix
// convert number -> matrix
// convert poly -> matrix
// convert vector -> matrix
// convert bigint -> matrix
// convert int -> matrix
// convert intvec -> matrix
// convert ideal -> module
// convert matrix -> module
// convert vector -> module
// convert bigint -> number
// convert int -> number
// convert number -> poly
// convert bigint -> poly
// convert int -> poly
// convert list -> resolution
// convert poly -> vector
// convert bigint -> vector
// convert int -> vector
// convert int -> bigint
// convert int -> intvec
// convert string -> link
// convert resolution -> list
/*---------------------------------------------*/
// token 61 : =
// token 62 : >
// token 60 : <
// token 43 : +
// token 42 : *
// token 47 : /
// token 91 : [
// token 46 : .
// token 94 : ^
// token 44 : ,
// token 37 : %
// token 40 : (
// token 59 : ;
// token 258 : ..
// token 259 : ==
// token 260 : >=
// token 261 : <=
// token 262 : --
// token 263 : not
// token 264 : <>
// token 265 : ++
// token 266 : ::
// token 269 : bigintmat
// token 270 : intmat
// token 271 : proc
// token 272 : ring
// token 274 : ideal
// token 275 : map
// token 276 : matrix
// token 277 : module
// token 278 : number
// token 279 : poly
// token 280 : resolution
// token 281 : vector
// token 282 : betti
// token 283 : gen
// token 284 : fetch
// token 285 : freemodule
// token 286 : keepring
// token 287 : imap
// token 288 : koszul
// token 289 : maxideal
// token 290 : monomial
// token 291 : par
// token 292 : preimage
// token 293 : var
// token 295 : degBound
// token 296 : multBound
// token 297 : noether
// token 298 : minpoly
// token 299 : nothing
// token 312 : example
// token 313 : export
// token 315 : kill
// token 316 : LIB
// token 317 : listvar
// token 318 : setring
// token 319 : type
// token 326 : apply
// token 327 : ASSUME
// token 328 : break
// token 329 : continue
// token 330 : else
// token 331 : eval
// token 332 : quote
// token 334 : forif
// token 337 : return
// token 338 : parameter
// token 342 : command
// token 343 : any_type
// token 344 : identifier
// token 355 : alias
// token 356 : align
// token 357 : attrib
// token 358 : bareiss
// token 359 : bigint
// token 360 : branchTo
// token 361 : bracket
// token 362 : breakpoint
// token 363 : char
// token 364 : charstr
// token 365 : char_series
// token 366 : chinrem
// token 370 : close
// token 371 : coeffs
// token 372 : coef
// token 373 : ncols
// token 374 : cleardenom
// token 375 : contract
// token 376 : size
// token 377 : cring
// token 378 : dbprint
// token 379 : def
// token 380 : defined
// token 381 : deg
// token 382 : degree
// token 383 : delete
// token 384 : denominator
// token 385 : det
// token 386 : diff
// token 387 : dim
// token 388 : division
// token 389 : dump
// token 390 : eliminate
// token 391 : RETURN
// token 392 : envelope
// token 393 : ERROR
// token 394 : execute
// token 395 : exportto
// token 396 : extgcd
// token 397 : factorize
// token 398 : farey
// token 399 : find
// token 400 : facstd
// token 401 : factmodd
// token 402 : frwalk
// token 403 : fglm
// token 404 : fglmquot
// token 405 : finduni
// token 406 : gcd
// token 407 : getdump
// token 408 : highcorner
// token 409 : hilb
// token 410 : homog
// token 411 : hres
// token 412 : impart
// token 413 : importfrom
// token 414 : indepSet
// token 415 : insert
// token 416 : int
// token 417 : div
// token 418 : interpolation
// token 419 : interred
// token 420 : intersect
// token 421 : intvec
// token 422 : rvar
// token 423 : jacob
// token 424 : janet
// token 425 : jet
// token 426 : kbase
// token 427 : kernel
// token 428 : killattrib
// token 429 : kres
// token 430 : laguerre
// token 431 : lead
// token 432 : leadcoef
// token 433 : leadexp
// token 434 : leadmonom
// token 435 : liftstd
// token 436 : lift
// token 437 : link
// token 438 : list
// token 439 : load
// token 440 : lres
// token 441 : ludecomp
// token 442 : luinverse
// token 443 : lusolve
// token 444 : memory
// token 445 : minbase
// token 446 : minor
// token 447 : minres
// token 448 : modulo
// token 449 : monitor
// token 450 : mpresmat
// token 451 : mres
// token 452 : mstd
// token 453 : mult
// token 454 : nameof
// token 455 : names
// token 456 : newstruct
// token 457 : ncalgebra
// token 458 : nc_algebra
// token 459 : convhull
// token 460 : npars
// token 461 : numerator
// token 462 : nvars
// token 463 : ord
// token 464 : open
// token 465 : oppose
// token 466 : opposite
// token 467 : option
// token 468 : ordstr
// token 469 : package
// token 470 : pardeg
// token 472 : parstr
// token 473 : primefactors
// token 474 : prime
// token 475 : print
// token 476 : prune
// token 477 : qhweight
// token 478 : qring
// token 479 : qrds
// token 480 : quotient
// token 481 : random
// token 482 : rank
// token 483 : read
// token 484 : reduce
// token 485 : regularity
// token 486 : repart
// token 487 : nres
// token 488 : reservedName
// token 489 : resultant
// token 490 : ringlist
// token 491 : ring_list
// token 492 : nrows
// token 493 : sba
// token 494 : simplex
// token 495 : simplify
// token 496 : slimgb
// token 497 : sortvec
// token 498 : sqrfree
// token 499 : sres
// token 500 : status
// token 501 : std
// token 502 : string
// token 503 : subst
// token 504 : system
// token 505 : syz
// token 506 : test
// token 507 : transpose
// token 508 : trace
// token 509 : twostd
// token 510 : typeof
// token 511 : univariate
// token 513 : uressolve
// token 514 : vandermonde
// token 515 : variables
// token 516 : varstr
// token 517 : vdim
// token 518 : waitfirst
// token 519 : waitall
// token 520 : wedge
// token 521 : weight
// token 522 : write
// token 523 : echo
// token 524 : pagewidth
// token 525 : timer
// token 526 : rtimer
// token 527 : TRACE
// token 528 : voice
// token 529 : short
// token 530 : printlevel
/*--max. token: 531, gr: 340 --*/
/*---------------------------------------------*/
const struct sValCmdTab dArithTab1[]=
{
 { 40,11 },
 { 45,2 },
 { 262,1 },
 { 263,143 },
 { 265,0 },
 { 269,22 },
 { 270,95 },
 { 271,165 },
 { 272,179 },
 { 274,82 },
 { 275,124 },
 { 276,125 },
 { 277,132 },
 { 278,144 },
 { 279,159 },
 { 280,174 },
 { 281,217 },
 { 282,15 },
 { 283,67 },
 { 285,72 },
 { 289,126 },
 { 290,134 },
 { 291,155 },
 { 292,161 },
 { 293,220 },
 { 318,189 },
 { 357,12 },
 { 358,13 },
 { 359,19 },
 { 363,23 },
 { 364,25 },
 { 365,24 },
 { 368,147 },
 { 370,26 },
 { 373,27 },
 { 374,33 },
 { 376,35 },
 { 377,48 },
 { 379,49 },
 { 380,56 },
 { 381,51 },
 { 382,54 },
 { 384,57 },
 { 385,59 },
 { 387,63 },
 { 389,66 },
 { 392,200 },
 { 393,69 },
 { 394,68 },
 { 397,70 },
 { 400,73 },
 { 405,71 },
 { 407,74 },
 { 408,75 },
 { 409,77 },
 { 410,80 },
 { 412,87 },
 { 414,88 },
 { 416,89 },
 { 419,93 },
 { 421,97 },
 { 422,99 },
 { 423,102 },
 { 424,105 },
 { 426,106 },
 { 428,111 },
 { 431,112 },
 { 432,116 },
 { 433,118 },
 { 434,120 },
 { 437,122 },
 { 438,123 },
 { 439,225 },
 { 441,108 },
 { 444,127 },
 { 445,128 },
 { 447,130 },
 { 449,133 },
 { 452,137 },
 { 453,135 },
 { 454,139 },
 { 455,140 },
 { 459,226 },
 { 460,148 },
 { 461,58 },
 { 462,149 },
 { 463,152 },
 { 464,150 },
 { 466,201 },
 { 467,151 },
 { 468,154 },
 { 470,156 },
 { 472,157 },
 { 473,109 },
 { 474,162 },
 { 475,163 },
 { 476,166 },
 { 477,167 },
 { 482,169 },
 { 483,170 },
 { 485,171 },
 { 486,172 },
 { 488,173 },
 { 490,176 },
 { 491,177 },
 { 492,181 },
 { 493,187 },
 { 496,190 },
 { 497,192 },
 { 498,194 },
 { 501,195 },
 { 502,197 },
 { 505,198 },
 { 507,207 },
 { 508,203 },
 { 509,202 },
 { 510,212 },
 { 511,213 },
 { 515,214 },
 { 516,221 },
 { 517,218 },
 { 518,227 },
 { 519,228 },
 { 521,223 },
 { 10000,0 }
};
#define JJTAB1LEN 124
const struct sValCmdTab dArithTab2[]=
{
 { 37,93 },
 { 38,139 },
 { 40,191 },
 { 42,43 },
 { 43,1 },
 { 45,25 },
 { 47,79 },
 { 58,196 },
 { 60,112 },
 { 62,130 },
 { 91,175 },
 { 94,98 },
 { 124,140 },
 { 258,174 },
 { 259,141 },
 { 260,121 },
 { 261,103 },
 { 264,160 },
 { 266,0 },
 { 282,200 },
 { 284,244 },
 { 287,262 },
 { 288,279 },
 { 356,197 },
 { 357,199 },
 { 361,204 },
 { 366,205 },
 { 371,209 },
 { 372,208 },
 { 375,213 },
 { 381,214 },
 { 383,217 },
 { 386,218 },
 { 387,225 },
 { 388,227 },
 { 390,229 },
 { 395,233 },
 { 396,234 },
 { 397,237 },
 { 398,239 },
 { 399,247 },
 { 400,238 },
 { 402,248 },
 { 403,245 },
 { 404,246 },
 { 406,249 },
 { 409,253 },
 { 410,255 },
 { 411,261 },
 { 413,263 },
 { 414,264 },
 { 415,265 },
 { 417,89 },
 { 418,266 },
 { 420,267 },
 { 424,269 },
 { 425,270 },
 { 426,275 },
 { 427,277 },
 { 428,278 },
 { 429,281 },
 { 435,284 },
 { 436,282 },
 { 439,286 },
 { 440,287 },
 { 448,288 },
 { 449,290 },
 { 450,291 },
 { 451,293 },
 { 456,292 },
 { 457,297 },
 { 458,301 },
 { 465,305 },
 { 472,306 },
 { 473,295 },
 { 475,307 },
 { 480,308 },
 { 481,311 },
 { 482,312 },
 { 483,313 },
 { 484,314 },
 { 487,320 },
 { 493,322 },
 { 495,324 },
 { 498,328 },
 { 499,331 },
 { 500,329 },
 { 501,333 },
 { 505,339 },
 { 516,341 },
 { 518,342 },
 { 519,343 },
 { 520,344 },
 { 10000,0 }
};
#define JJTAB2LEN 93
/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// identifier table for Singular
//
#ifdef MODULE_GENERATOR
#define omAlloc0(A) malloc(A)
#endif
void iiInitCmdName()
{
  sArithBase.nCmdUsed      = 0;
  sArithBase.nCmdAllocated = 235;
  sArithBase.sCmds = (cmdnames*)omAlloc0(sArithBase.nCmdAllocated*sizeof(cmdnames));

  // name-string                   alias  tokval toktype index
  iiArithAddCmd("$INVALID$",           0,  -1, 0, 0);
  iiArithAddCmd("ASSUME",              0, 327, 327, 1);
  iiArithAddCmd("ERROR",               0, 393, CMD_1, 2);
  iiArithAddCmd("GCD",                 2, 406, CMD_2, 3);
  iiArithAddCmd("IN",                  1, 431, CMD_1, 4);
  iiArithAddCmd("LIB",                 0, 316, SYSVAR, 5);
  iiArithAddCmd("NF",                  1, 484, CMD_M, 6);
  iiArithAddCmd("RETURN",              0, 391, 337, 7);
  iiArithAddCmd("TRACE",               0, 527, SYSVAR, 8);
  iiArithAddCmd("alias",               0, 355, 338, 9);
  iiArithAddCmd("align",               0, 356, CMD_2, 10);
  iiArithAddCmd("and",                 0,  38, '&', 11);
  iiArithAddCmd("apply",               0, 326, 326, 12);
  iiArithAddCmd("attrib",              0, 357, CMD_123, 13);
  iiArithAddCmd("bareiss",             0, 358, 304, 14);
  iiArithAddCmd("betti",               0, 282, CMD_12, 15);
  iiArithAddCmd("bigint",              0, 359, ROOT_DECL, 16);
  iiArithAddCmd("bigintmat",           0, 269, 269, 17);
  iiArithAddCmd("bracket",             0, 361, CMD_2, 18);
  iiArithAddCmd("branchTo",            0, 360, CMD_M, 19);
  iiArithAddCmd("break",               0, 328, 328, 20);
  iiArithAddCmd("breakpoint",          0, 362, CMD_M, 21);
  iiArithAddCmd("char",                0, 363, CMD_1, 22);
  iiArithAddCmd("char_series",         0, 365, CMD_1, 23);
  iiArithAddCmd("charstr",             0, 364, CMD_1, 24);
  iiArithAddCmd("chinrem",             0, 366, CMD_2, 25);
  iiArithAddCmd("cleardenom",          0, 374, CMD_1, 26);
  iiArithAddCmd("close",               0, 370, CMD_1, 27);
  iiArithAddCmd("coef",                0, 372, CMD_M, 28);
  iiArithAddCmd("coeffs",              0, 371, CMD_23, 29);
  iiArithAddCmd("continue",            0, 329, 329, 30);
  iiArithAddCmd("contract",            0, 375, CMD_2, 31);
  iiArithAddCmd("convhull",            0, 459, CMD_1, 32);
  iiArithAddCmd("cring",               0, 377, ROOT_DECL, 33);
  iiArithAddCmd("dbprint",             0, 378, CMD_M, 34);
  iiArithAddCmd("def",                 0, 379, ROOT_DECL, 35);
  iiArithAddCmd("defined",             0, 380, CMD_1, 36);
  iiArithAddCmd("deg",                 0, 381, CMD_12, 37);
  iiArithAddCmd("degBound",            0, 295, SYSVAR, 38);
  iiArithAddCmd("degree",              0, 382, CMD_1, 39);
  iiArithAddCmd("delete",              0, 383, CMD_2, 40);
  iiArithAddCmd("denominator",         0, 384, CMD_1, 41);
  iiArithAddCmd("det",                 0, 385, CMD_1, 42);
  iiArithAddCmd("diff",                0, 386, CMD_2, 43);
  iiArithAddCmd("dim",                 0, 387, CMD_12, 44);
  iiArithAddCmd("div",                 0, 417, '/', 45);
  iiArithAddCmd("division",            0, 388, CMD_M, 46);
  iiArithAddCmd("dump",                0, 389, CMD_1, 47);
  iiArithAddCmd("echo",                0, 523, SYSVAR, 48);
  iiArithAddCmd("eliminate",           0, 390, CMD_23, 49);
  iiArithAddCmd("else",                0, 330, 330, 50);
  iiArithAddCmd("envelope",            0, 392, CMD_1, 51);
  iiArithAddCmd("eval",                0, 331, 331, 52);
  iiArithAddCmd("example",             0, 312, 312, 53);
  iiArithAddCmd("execute",             0, 394, CMD_1, 54);
  iiArithAddCmd("export",              0, 313, 313, 55);
  iiArithAddCmd("exportto",            0, 395, CMD_2, 56);
  iiArithAddCmd("extgcd",              0, 396, CMD_2, 57);
  iiArithAddCmd("facstd",              0, 400, CMD_12, 58);
  iiArithAddCmd("factmodd",            0, 401, CMD_M, 59);
  iiArithAddCmd("factorize",           0, 397, CMD_12, 60);
  iiArithAddCmd("farey",               0, 398, CMD_2, 61);
  iiArithAddCmd("fetch",               0, 284, CMD_M, 62);
  iiArithAddCmd("fglm",                0, 403, CMD_2, 63);
  iiArithAddCmd("fglmquot",            0, 404, CMD_2, 64);
  iiArithAddCmd("find",                0, 399, CMD_23, 65);
  iiArithAddCmd("finduni",             0, 405, CMD_1, 66);
  iiArithAddCmd("forif",               0, 334, 334, 67);
  iiArithAddCmd("freemodule",          0, 285, CMD_1, 68);
  iiArithAddCmd("frwalk",              0, 402, CMD_23, 69);
  iiArithAddCmd("gcd",                 0, 406, CMD_2, 70);
  iiArithAddCmd("gen",                 0, 283, CMD_1, 71);
  iiArithAddCmd("getdump",             0, 407, CMD_1, 72);
  iiArithAddCmd("highcorner",          0, 408, CMD_1, 73);
  iiArithAddCmd("hilb",                0, 409, CMD_123, 74);
  iiArithAddCmd("homog",               0, 410, CMD_123, 75);
  iiArithAddCmd("hres",                0, 411, CMD_2, 76);
  iiArithAddCmd("ideal",               0, 274, 311, 77);
  iiArithAddCmd("if",                  0, 334, 334, 78);
  iiArithAddCmd("imap",                0, 287, CMD_2, 79);
  iiArithAddCmd("impart",              0, 412, CMD_1, 80);
  iiArithAddCmd("importfrom",          0, 413, CMD_2, 81);
  iiArithAddCmd("indepSet",            0, 414, CMD_12, 82);
  iiArithAddCmd("insert",              0, 415, CMD_23, 83);
  iiArithAddCmd("int",                 0, 416, ROOT_DECL, 84);
  iiArithAddCmd("interpolation",       0, 418, CMD_2, 85);
  iiArithAddCmd("interred",            0, 419, CMD_1, 86);
  iiArithAddCmd("intersect",           0, 420, CMD_M, 87);
  iiArithAddCmd("intmat",              0, 270, 270, 88);
  iiArithAddCmd("intvec",              0, 421, ROOT_DECL_LIST, 89);
  iiArithAddCmd("jacob",               0, 423, CMD_1, 90);
  iiArithAddCmd("janet",               0, 424, CMD_12, 91);
  iiArithAddCmd("jet",                 0, 425, CMD_M, 92);
  iiArithAddCmd("kbase",               0, 426, CMD_12, 93);
  iiArithAddCmd("keepring",            0, 286, 286, 94);
  iiArithAddCmd("kernel",              0, 427, CMD_2, 95);
  iiArithAddCmd("kill",                0, 315, 315, 96);
  iiArithAddCmd("killattrib",          0, 428, CMD_12, 97);
  iiArithAddCmd("koszul",              0, 288, CMD_23, 98);
  iiArithAddCmd("kres",                0, 429, CMD_2, 99);
  iiArithAddCmd("laguerre",            0, 430, CMD_3, 100);
  iiArithAddCmd("lead",                0, 431, CMD_1, 101);
  iiArithAddCmd("leadcoef",            0, 432, CMD_1, 102);
  iiArithAddCmd("leadexp",             0, 433, CMD_1, 103);
  iiArithAddCmd("leadmonom",           0, 434, CMD_1, 104);
  iiArithAddCmd("lift",                0, 436, CMD_M, 105);
  iiArithAddCmd("liftstd",             0, 435, CMD_M, 106);
  iiArithAddCmd("link",                0, 437, ROOT_DECL, 107);
  iiArithAddCmd("list",                0, 438, ROOT_DECL_LIST, 108);
  iiArithAddCmd("listvar",             0, 317, 317, 109);
  iiArithAddCmd("load",                0, 439, CMD_12, 110);
  iiArithAddCmd("lres",                0, 440, CMD_2, 111);
  iiArithAddCmd("ludecomp",            0, 441, CMD_1, 112);
  iiArithAddCmd("luinverse",           0, 442, CMD_M, 113);
  iiArithAddCmd("lusolve",             0, 443, CMD_M, 114);
  iiArithAddCmd("map",                 0, 275, RING_DECL, 115);
  iiArithAddCmd("matrix",              0, 276, 276, 116);
  iiArithAddCmd("maxideal",            0, 289, CMD_1, 117);
  iiArithAddCmd("memory",              0, 444, CMD_1, 118);
  iiArithAddCmd("minbase",             0, 445, CMD_1, 119);
  iiArithAddCmd("minor",               0, 446, CMD_M, 120);
  iiArithAddCmd("minpoly",             0, 298, SYSVAR, 121);
  iiArithAddCmd("minres",              0, 447, CMD_1, 122);
  iiArithAddCmd("mod",                 0,  37, '/', 123);
  iiArithAddCmd("module",              0, 277, 311, 124);
  iiArithAddCmd("modulo",              0, 448, CMD_2, 125);
  iiArithAddCmd("monitor",             0, 449, CMD_12, 126);
  iiArithAddCmd("monomial",            0, 290, CMD_1, 127);
  iiArithAddCmd("mpresmat",            0, 450, CMD_2, 128);
  iiArithAddCmd("mres",                0, 451, CMD_2, 129);
  iiArithAddCmd("mstd",                0, 452, CMD_1, 130);
  iiArithAddCmd("mult",                0, 453, CMD_1, 131);
  iiArithAddCmd("multBound",           0, 296, SYSVAR, 132);
  iiArithAddCmd("multiplicity",        1, 453, CMD_1, 133);
  iiArithAddCmd("nameof",              0, 454, CMD_1, 134);
  iiArithAddCmd("names",               0, 455, CMD_M, 135);
  iiArithAddCmd("nc_algebra",          0, 458, CMD_2, 136);
  iiArithAddCmd("ncalgebra",           2, 457, CMD_2, 137);
  iiArithAddCmd("ncols",               0, 373, CMD_1, 138);
  iiArithAddCmd("newstruct",           0, 456, CMD_23, 139);
  iiArithAddCmd("noether",             0, 297, SYSVAR, 140);
  iiArithAddCmd("not",                 0, 263, 263, 141);
  iiArithAddCmd("npars",               0, 460, CMD_1, 142);
  iiArithAddCmd("nres",                0, 487, CMD_2, 143);
  iiArithAddCmd("nrows",               0, 492, CMD_1, 144);
  iiArithAddCmd("number",              0, 278, RING_DECL, 145);
  iiArithAddCmd("numerator",           0, 461, CMD_1, 146);
  iiArithAddCmd("nvars",               0, 462, CMD_1, 147);
  iiArithAddCmd("open",                0, 464, CMD_1, 148);
  iiArithAddCmd("oppose",              0, 465, CMD_2, 149);
  iiArithAddCmd("opposite",            0, 466, CMD_1, 150);
  iiArithAddCmd("option",              0, 467, CMD_M, 151);
  iiArithAddCmd("or",                  0, 124, '&', 152);
  iiArithAddCmd("ord",                 0, 463, CMD_1, 153);
  iiArithAddCmd("ordstr",              0, 468, CMD_1, 154);
  iiArithAddCmd("package",             0, 469, ROOT_DECL, 155);
  iiArithAddCmd("pagewidth",           0, 524, SYSVAR, 156);
  iiArithAddCmd("par",                 0, 291, CMD_1, 157);
  iiArithAddCmd("parameter",           0, 338, 338, 158);
  iiArithAddCmd("pardeg",              0, 470, CMD_1, 159);
  iiArithAddCmd("parstr",              0, 472, CMD_12, 160);
  iiArithAddCmd("poly",                0, 279, RING_DECL, 161);
  iiArithAddCmd("preimage",            0, 292, 304, 162);
  iiArithAddCmd("prime",               0, 474, CMD_1, 163);
  iiArithAddCmd("primefactors",        0, 473, CMD_12, 164);
  iiArithAddCmd("print",               0, 475, CMD_12, 165);
  iiArithAddCmd("printlevel",          0, 530, SYSVAR, 166);
  iiArithAddCmd("proc",                0, 271, 271, 167);
  iiArithAddCmd("prune",               0, 476, CMD_1, 168);
  iiArithAddCmd("qhweight",            0, 477, CMD_1, 169);
  iiArithAddCmd("qrds",                0, 479, CMD_M, 170);
  iiArithAddCmd("qring",               0, 478, ROOT_DECL, 171);
  iiArithAddCmd("quote",               0, 332, 332, 172);
  iiArithAddCmd("quotient",            0, 480, CMD_2, 173);
  iiArithAddCmd("random",              0, 481, CMD_23, 174);
  iiArithAddCmd("rank",                0, 482, CMD_12, 175);
  iiArithAddCmd("read",                0, 483, CMD_12, 176);
  iiArithAddCmd("reduce",              0, 484, CMD_M, 177);
  iiArithAddCmd("regularity",          0, 485, CMD_1, 178);
  iiArithAddCmd("repart",              0, 486, CMD_1, 179);
  iiArithAddCmd("reservedName",        0, 488, CMD_M, 180);
  iiArithAddCmd("resolution",          0, 280, RING_DECL, 181);
  iiArithAddCmd("resultant",           0, 489, CMD_3, 182);
  iiArithAddCmd("return",              0, 337, 337, 183);
  iiArithAddCmd("ring",                0, 272, 272, 184);
  iiArithAddCmd("ring_list",           0, 491, CMD_1, 185);
  iiArithAddCmd("ringlist",            0, 490, CMD_1, 186);
  iiArithAddCmd("rtimer",              0, 526, SYSVAR, 187);
  iiArithAddCmd("rvar",                0, 422, CMD_1, 188);
  iiArithAddCmd("sba",                 0, 493, CMD_123, 189);
  iiArithAddCmd("setring",             0, 318, 318, 190);
  iiArithAddCmd("short",               0, 529, SYSVAR, 191);
  iiArithAddCmd("simplex",             0, 494, CMD_M, 192);
  iiArithAddCmd("simplify",            0, 495, CMD_2, 193);
  iiArithAddCmd("size",                0, 376, CMD_1, 194);
  iiArithAddCmd("slimgb",              0, 496, CMD_1, 195);
  iiArithAddCmd("sortvec",             0, 497, CMD_1, 196);
  iiArithAddCmd("sqrfree",             0, 498, CMD_12, 197);
  iiArithAddCmd("sres",                0, 499, CMD_2, 198);
  iiArithAddCmd("status",              0, 500, CMD_M, 199);
  iiArithAddCmd("std",                 0, 501, CMD_M, 200);
  iiArithAddCmd("string",              0, 502, ROOT_DECL_LIST, 201);
  iiArithAddCmd("subst",               0, 503, CMD_M, 202);
  iiArithAddCmd("system",              0, 504, CMD_M, 203);
  iiArithAddCmd("syz",                 0, 505, CMD_12, 204);
  iiArithAddCmd("test",                0, 506, CMD_M, 205);
  iiArithAddCmd("timer",               0, 525, SYSVAR, 206);
  iiArithAddCmd("trace",               0, 508, CMD_1, 207);
  iiArithAddCmd("transpose",           0, 507, CMD_1, 208);
  iiArithAddCmd("twostd",              0, 509, CMD_1, 209);
  iiArithAddCmd("type",                0, 319, 319, 210);
  iiArithAddCmd("typeof",              0, 510, CMD_1, 211);
  iiArithAddCmd("univariate",          0, 511, CMD_1, 212);
  iiArithAddCmd("uressolve",           0, 513, CMD_M, 213);
  iiArithAddCmd("vandermonde",         0, 514, CMD_3, 214);
  iiArithAddCmd("var",                 0, 293, CMD_1, 215);
  iiArithAddCmd("variables",           0, 515, CMD_1, 216);
  iiArithAddCmd("varstr",              0, 516, CMD_12, 217);
  iiArithAddCmd("vdim",                0, 517, CMD_1, 218);
  iiArithAddCmd("vector",              0, 281, RING_DECL, 219);
  iiArithAddCmd("verbose",             2, 467, CMD_M, 220);
  iiArithAddCmd("voice",               0, 528, SYSVAR, 221);
  iiArithAddCmd("waitall",             0, 519, CMD_12, 222);
  iiArithAddCmd("waitfirst",           0, 518, CMD_12, 223);
  iiArithAddCmd("wedge",               0, 520, CMD_2, 224);
  iiArithAddCmd("weight",              0, 521, CMD_1, 225);
  iiArithAddCmd("whileif",             0, 334, 334, 226);
  iiArithAddCmd("write",               0, 522, CMD_M, 227);
  iiArithAddCmd("exit",                0,  -1, 0, 228);
  iiArithAddCmd("for",                 0,  -1, 0, 229);
  iiArithAddCmd("help",                0,  -1, 0, 230);
  iiArithAddCmd("newline",             0,  -1, 0, 231);
  iiArithAddCmd("pause",               2,  -1, 0, 232);
  iiArithAddCmd("quit",                0,  -1, 0, 233);
  iiArithAddCmd("while",               0,  -1, 0, 234);
/* end of list marker */
  sArithBase.nLastIdentifier = 227;
}
#define LAST_IDENTIFIER 227
